pub struct Grid {
pub columns: Vec<GridTrack>,
pub rows: Vec<GridTrack>,
pub column_gap: f32,
pub row_gap: f32,
}Expand description
A layout engine that computes coordinates for children positioned in a 2D grid.
Fields
columns: Vec<GridTrack>rows: Vec<GridTrack>column_gap: f32row_gap: f32Implementations
Sourceimpl Grid
impl Grid
Sourcepub fn new(
columns: Vec<GridTrack>,
rows: Vec<GridTrack>,
column_gap: f32,
row_gap: f32,
) -> Self
pub fn new( columns: Vec<GridTrack>, rows: Vec<GridTrack>, column_gap: f32, row_gap: f32, ) -> Self
Creates a new Grid layout engine.
Sourcepub fn compute_layout_rects(
&self,
bounds: Rect,
subviews: &[&dyn LayoutView],
placements: &[Option<GridPlacement>],
cache: &mut LayoutCache,
) -> Vec<Rect>
pub fn compute_layout_rects( &self, bounds: Rect, subviews: &[&dyn LayoutView], placements: &[Option<GridPlacement>], cache: &mut LayoutCache, ) -> Vec<Rect>
Computes the rects for children based on track sizing and grid placements.
pub fn compute_layout_rects_incremental( &self, bounds: Rect, container_hash: u64, subviews: &[&dyn LayoutView], placements: &[Option<GridPlacement>], cache: &mut LayoutCache, ) -> Vec<Rect>